@@ -2,6 +2,9 @@
 #define MAINWINDOW_H
 
 #include <QMainWindow>
+#include <QStringList>
+
+#define MIN_DB -100
 
 namespace Ui {
     class MainWindow;
@@ -24,10 +27,14 @@ private:
     Ui::MainWindow *ui;
 
     int maxVol;
+    const QStringList *sources;
 
 private slots:
-    void updateValues(float value);
     void resetMaxValue();
+    void setDbScale();
+    void setLinearScale();
+    void sourceChanged(QString source);
+    void updateValues(float value);
 };
 
 #endif // MAINWINDOW_H
